# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKBinaryMathematicalMorphologyPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkErodeObjectMorphologyImageFilterPython
else:
    import _itkErodeObjectMorphologyImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkFlatStructuringElementPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.ITKCommonBasePython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkNeighborhoodPython
import itk.itkBoxImageFilterPython
import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkDilateObjectMorphologyImageFilterPython
import itk.itkImageBoundaryConditionPython

def itkErodeObjectMorphologyImageFilterIF2IF2SE2_New():
    return itkErodeObjectMorphologyImageFilterIF2IF2SE2.New()

class itkErodeObjectMorphologyImageFilterIF2IF2SE2(itk.itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF2IF2SE2_Superclass):
    r"""Proxy of C++ itkErodeObjectMorphologyImageFilterIF2IF2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkErodeObjectMorphologyImageFilterIF2IF2SE2_Pointer"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF2IF2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkErodeObjectMorphologyImageFilterIF2IF2SE2_Pointer"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF2IF2SE2_Clone(self)

    def SetErodeValue(self, objectValue):
        r"""
        SetErodeValue(self, objectValue)

        Parameters
        ----------
        objectValue: float

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF2IF2SE2_SetErodeValue(self, objectValue)

    def GetErodeValue(self):
        r"""GetErodeValue(self) -> float"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF2IF2SE2_GetErodeValue(self)

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF2IF2SE2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> float"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF2IF2SE2_GetBackgroundValue(self)
    KernelGreaterThanComparableCheck = _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF2IF2SE2_KernelGreaterThanComparableCheck
    
    __swig_destroy__ = _itkErodeObjectMorphologyImageFilterPython.delete_itkErodeObjectMorphologyImageFilterIF2IF2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkErodeObjectMorphologyImageFilterIF2IF2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF2IF2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkErodeObjectMorphologyImageFilterIF2IF2SE2

        Create a new object of the class itkErodeObjectMorphologyImageFilterIF2IF2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkErodeObjectMorphologyImageFilterIF2IF2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkErodeObjectMorphologyImageFilterIF2IF2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkErodeObjectMorphologyImageFilterIF2IF2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkErodeObjectMorphologyImageFilterIF2IF2SE2 in _itkErodeObjectMorphologyImageFilterPython:
_itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF2IF2SE2_swigregister(itkErodeObjectMorphologyImageFilterIF2IF2SE2)

def itkErodeObjectMorphologyImageFilterIF3IF3SE3_New():
    return itkErodeObjectMorphologyImageFilterIF3IF3SE3.New()

class itkErodeObjectMorphologyImageFilterIF3IF3SE3(itk.itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIF3IF3SE3_Superclass):
    r"""Proxy of C++ itkErodeObjectMorphologyImageFilterIF3IF3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkErodeObjectMorphologyImageFilterIF3IF3SE3_Pointer"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF3IF3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkErodeObjectMorphologyImageFilterIF3IF3SE3_Pointer"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF3IF3SE3_Clone(self)

    def SetErodeValue(self, objectValue):
        r"""
        SetErodeValue(self, objectValue)

        Parameters
        ----------
        objectValue: float

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF3IF3SE3_SetErodeValue(self, objectValue)

    def GetErodeValue(self):
        r"""GetErodeValue(self) -> float"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF3IF3SE3_GetErodeValue(self)

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: float

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF3IF3SE3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> float"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF3IF3SE3_GetBackgroundValue(self)
    KernelGreaterThanComparableCheck = _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF3IF3SE3_KernelGreaterThanComparableCheck
    
    __swig_destroy__ = _itkErodeObjectMorphologyImageFilterPython.delete_itkErodeObjectMorphologyImageFilterIF3IF3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkErodeObjectMorphologyImageFilterIF3IF3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF3IF3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkErodeObjectMorphologyImageFilterIF3IF3SE3

        Create a new object of the class itkErodeObjectMorphologyImageFilterIF3IF3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkErodeObjectMorphologyImageFilterIF3IF3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkErodeObjectMorphologyImageFilterIF3IF3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkErodeObjectMorphologyImageFilterIF3IF3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkErodeObjectMorphologyImageFilterIF3IF3SE3 in _itkErodeObjectMorphologyImageFilterPython:
_itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIF3IF3SE3_swigregister(itkErodeObjectMorphologyImageFilterIF3IF3SE3)

def itkErodeObjectMorphologyImageFilterISS2ISS2SE2_New():
    return itkErodeObjectMorphologyImageFilterISS2ISS2SE2.New()

class itkErodeObjectMorphologyImageFilterISS2ISS2SE2(itk.itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS2ISS2SE2_Superclass):
    r"""Proxy of C++ itkErodeObjectMorphologyImageFilterISS2ISS2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkErodeObjectMorphologyImageFilterISS2ISS2SE2_Pointer"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS2ISS2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkErodeObjectMorphologyImageFilterISS2ISS2SE2_Pointer"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS2ISS2SE2_Clone(self)

    def SetErodeValue(self, objectValue):
        r"""
        SetErodeValue(self, objectValue)

        Parameters
        ----------
        objectValue: short

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS2ISS2SE2_SetErodeValue(self, objectValue)

    def GetErodeValue(self):
        r"""GetErodeValue(self) -> short"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS2ISS2SE2_GetErodeValue(self)

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS2ISS2SE2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> short"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS2ISS2SE2_GetBackgroundValue(self)
    KernelGreaterThanComparableCheck = _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS2ISS2SE2_KernelGreaterThanComparableCheck
    
    __swig_destroy__ = _itkErodeObjectMorphologyImageFilterPython.delete_itkErodeObjectMorphologyImageFilterISS2ISS2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkErodeObjectMorphologyImageFilterISS2ISS2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS2ISS2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkErodeObjectMorphologyImageFilterISS2ISS2SE2

        Create a new object of the class itkErodeObjectMorphologyImageFilterISS2ISS2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkErodeObjectMorphologyImageFilterISS2ISS2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkErodeObjectMorphologyImageFilterISS2ISS2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkErodeObjectMorphologyImageFilterISS2ISS2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkErodeObjectMorphologyImageFilterISS2ISS2SE2 in _itkErodeObjectMorphologyImageFilterPython:
_itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS2ISS2SE2_swigregister(itkErodeObjectMorphologyImageFilterISS2ISS2SE2)

def itkErodeObjectMorphologyImageFilterISS3ISS3SE3_New():
    return itkErodeObjectMorphologyImageFilterISS3ISS3SE3.New()

class itkErodeObjectMorphologyImageFilterISS3ISS3SE3(itk.itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterISS3ISS3SE3_Superclass):
    r"""Proxy of C++ itkErodeObjectMorphologyImageFilterISS3ISS3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkErodeObjectMorphologyImageFilterISS3ISS3SE3_Pointer"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS3ISS3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkErodeObjectMorphologyImageFilterISS3ISS3SE3_Pointer"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS3ISS3SE3_Clone(self)

    def SetErodeValue(self, objectValue):
        r"""
        SetErodeValue(self, objectValue)

        Parameters
        ----------
        objectValue: short

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS3ISS3SE3_SetErodeValue(self, objectValue)

    def GetErodeValue(self):
        r"""GetErodeValue(self) -> short"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS3ISS3SE3_GetErodeValue(self)

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: short

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS3ISS3SE3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> short"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS3ISS3SE3_GetBackgroundValue(self)
    KernelGreaterThanComparableCheck = _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS3ISS3SE3_KernelGreaterThanComparableCheck
    
    __swig_destroy__ = _itkErodeObjectMorphologyImageFilterPython.delete_itkErodeObjectMorphologyImageFilterISS3ISS3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkErodeObjectMorphologyImageFilterISS3ISS3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS3ISS3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkErodeObjectMorphologyImageFilterISS3ISS3SE3

        Create a new object of the class itkErodeObjectMorphologyImageFilterISS3ISS3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkErodeObjectMorphologyImageFilterISS3ISS3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkErodeObjectMorphologyImageFilterISS3ISS3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkErodeObjectMorphologyImageFilterISS3ISS3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkErodeObjectMorphologyImageFilterISS3ISS3SE3 in _itkErodeObjectMorphologyImageFilterPython:
_itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterISS3ISS3SE3_swigregister(itkErodeObjectMorphologyImageFilterISS3ISS3SE3)

def itkErodeObjectMorphologyImageFilterIUC2IUC2SE2_New():
    return itkErodeObjectMorphologyImageFilterIUC2IUC2SE2.New()

class itkErodeObjectMorphologyImageFilterIUC2IUC2SE2(itk.itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC2IUC2SE2_Superclass):
    r"""Proxy of C++ itkErodeObjectMorphologyImageFilterIUC2IUC2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkErodeObjectMorphologyImageFilterIUC2IUC2SE2_Pointer"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC2IUC2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkErodeObjectMorphologyImageFilterIUC2IUC2SE2_Pointer"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC2IUC2SE2_Clone(self)

    def SetErodeValue(self, objectValue):
        r"""
        SetErodeValue(self, objectValue)

        Parameters
        ----------
        objectValue: unsigned char

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC2IUC2SE2_SetErodeValue(self, objectValue)

    def GetErodeValue(self):
        r"""GetErodeValue(self) -> unsigned char"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC2IUC2SE2_GetErodeValue(self)

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC2IUC2SE2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC2IUC2SE2_GetBackgroundValue(self)
    KernelGreaterThanComparableCheck = _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC2IUC2SE2_KernelGreaterThanComparableCheck
    
    __swig_destroy__ = _itkErodeObjectMorphologyImageFilterPython.delete_itkErodeObjectMorphologyImageFilterIUC2IUC2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkErodeObjectMorphologyImageFilterIUC2IUC2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC2IUC2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkErodeObjectMorphologyImageFilterIUC2IUC2SE2

        Create a new object of the class itkErodeObjectMorphologyImageFilterIUC2IUC2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkErodeObjectMorphologyImageFilterIUC2IUC2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkErodeObjectMorphologyImageFilterIUC2IUC2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkErodeObjectMorphologyImageFilterIUC2IUC2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkErodeObjectMorphologyImageFilterIUC2IUC2SE2 in _itkErodeObjectMorphologyImageFilterPython:
_itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC2IUC2SE2_swigregister(itkErodeObjectMorphologyImageFilterIUC2IUC2SE2)

def itkErodeObjectMorphologyImageFilterIUC3IUC3SE3_New():
    return itkErodeObjectMorphologyImageFilterIUC3IUC3SE3.New()

class itkErodeObjectMorphologyImageFilterIUC3IUC3SE3(itk.itkDilateObjectMorphologyImageFilterPython.itkDilateObjectMorphologyImageFilterIUC3IUC3SE3_Superclass):
    r"""Proxy of C++ itkErodeObjectMorphologyImageFilterIUC3IUC3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkErodeObjectMorphologyImageFilterIUC3IUC3SE3_Pointer"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC3IUC3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkErodeObjectMorphologyImageFilterIUC3IUC3SE3_Pointer"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC3IUC3SE3_Clone(self)

    def SetErodeValue(self, objectValue):
        r"""
        SetErodeValue(self, objectValue)

        Parameters
        ----------
        objectValue: unsigned char

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC3IUC3SE3_SetErodeValue(self, objectValue)

    def GetErodeValue(self):
        r"""GetErodeValue(self) -> unsigned char"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC3IUC3SE3_GetErodeValue(self)

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC3IUC3SE3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC3IUC3SE3_GetBackgroundValue(self)
    KernelGreaterThanComparableCheck = _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC3IUC3SE3_KernelGreaterThanComparableCheck
    
    __swig_destroy__ = _itkErodeObjectMorphologyImageFilterPython.delete_itkErodeObjectMorphologyImageFilterIUC3IUC3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkErodeObjectMorphologyImageFilterIUC3IUC3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC3IUC3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkErodeObjectMorphologyImageFilterIUC3IUC3SE3

        Create a new object of the class itkErodeObjectMorphologyImageFilterIUC3IUC3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkErodeObjectMorphologyImageFilterIUC3IUC3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkErodeObjectMorphologyImageFilterIUC3IUC3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkErodeObjectMorphologyImageFilterIUC3IUC3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkErodeObjectMorphologyImageFilterIUC3IUC3SE3 in _itkErodeObjectMorphologyImageFilterPython:
_itkErodeObjectMorphologyImageFilterPython.itkErodeObjectMorphologyImageFilterIUC3IUC3SE3_swigregister(itkErodeObjectMorphologyImageFilterIUC3IUC3SE3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def erode_object_morphology_image_filter(*args: itkt.ImageLike,  erode_value: int=..., background_value: int=..., kernel: itkt.FlatStructuringElement=..., object_value: int=..., use_boundary_condition: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ErodeObjectMorphologyImageFilter"""
    import itk

    kwarg_typehints = { 'erode_value':erode_value,'background_value':background_value,'kernel':kernel,'object_value':object_value,'use_boundary_condition':use_boundary_condition }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ErodeObjectMorphologyImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def erode_object_morphology_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKBinaryMathematicalMorphology.ErodeObjectMorphologyImageFilter
    erode_object_morphology_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    erode_object_morphology_image_filter.__doc__ = filter_object.__doc__



